# Happy Migrations: Hopefully no tears. (WIP)


TODO:
1. Logging into _happy_log
2. Log message to end user
   1. No migration to apply
   2. No migration to rollback
3. Create a test scenario


Make only edge methods run connect



Methods:
1. List migrations
2. List logs
3. Apply all
4. Apply one
5. Apply up to
6. Rollback one
7. Rollback up to
8. Rollback all
9. Mark as applied
10. Mark as pending